@@ -6,7 +6,7 @@
  * and the language files in subdirectory "../geshi/")
  *
  * @author  Nigel McNie
- * @version $Id: langcheck.php 1727 2008-08-08 13:36:52Z benbe $
+ * @version $Id: langcheck.php 2091 2009-05-23 13:11:36Z benbe $
  */
 header('Content-Type: text/html; charset=utf-8');
 
@@ -59,6 +59,10 @@ function report_error($type, $message) {
     }
 }
 
+function dupfind_strtolower(&$value){
+    $value = strtolower($value);
+}
+
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
@@ -315,7 +319,7 @@ if(!$error_abort) {
                     if(!is_integer($kw_key)) {
                         report_error(TYPE_WARNING, "Language file contains an key '$kw_key' in \$language_data['KEYWORDS'] that is not integer!");
                     } else if (!is_array($kw_value)) {
-                        report_error(TYPE_ERROR, "Language file contains a \$language_data['CASE_SENSITIVE']['$cs_value'] structure which is not an array!");
+                        report_error(TYPE_ERROR, "Language file contains a \$language_data['CASE_SENSITIVE']['$kw_value'] structure which is not an array!");
                     }
                 }
             }
@@ -464,6 +468,9 @@ if(!$error_abort) {
                         report_error(TYPE_NOTICE, "Language file contains an keyword ('$kw') at \$language_data['KEYWORDS'][$key][$id] which seems to be better suited for the symbols section!");
                     }
                 }
+                if(!$language_data['CASE_SENSITIVE'][$key]) {
+                    array_walk($keywords, 'dupfind_strtolower');
+                }
                 if(count($keywords) != count(array_unique($keywords))) {
                     $kw_diffs = array_count_values($keywords);
                     foreach($kw_diffs as $kw => $kw_count) {
@@ -473,6 +480,10 @@ if(!$error_abort) {
                     }
                 }
             }
+
+            $disallowed_before = "(?<![a-zA-Z0-9\$_\|\#;>|^&";
+            $disallowed_after = "(?![a-zA-Z0-9_\|%\\-&;";
+
             foreach($language_data['KEYWORDS'] as $key => $keywords) {
                 foreach($language_data['KEYWORDS'] as $key2 => $keywords2) {
                     if($key2 <= $key) {
@@ -480,6 +491,39 @@ if(!$error_abort) {
                     }
                     $kw_diffs = array_intersect($keywords, $keywords2);
                     foreach($kw_diffs as $kw) {
+                        if(isset($language_data['PARSER_CONTROL']['KEYWORDS'])) {
+                            //Check the precondition\post-cindition for the involved keyword groups
+                            $g1_pre = $disallowed_before;
+                            $g2_pre = $disallowed_before;
+                            $g1_post = $disallowed_after;
+                            $g2_post = $disallowed_after;
+                            if(isset($language_data['PARSER_CONTROL']['KEYWORDS']['DISALLOWED_BEFORE'])) {
+                                $g1_pre = $language_data['PARSER_CONTROL']['KEYWORDS']['DISALLOWED_BEFORE'];
+                                $g2_pre = $language_data['PARSER_CONTROL']['KEYWORDS']['DISALLOWED_BEFORE'];
+                            }
+                            if(isset($language_data['PARSER_CONTROL']['KEYWORDS']['DISALLOWED_AFTER'])) {
+                                $g1_post = $language_data['PARSER_CONTROL']['KEYWORDS']['DISALLOWED_AFTER'];
+                                $g2_post = $language_data['PARSER_CONTROL']['KEYWORDS']['DISALLOWED_AFTER'];
+                            }
+
+                            if(isset($language_data['PARSER_CONTROL']['KEYWORDS'][$key]['DISALLOWED_BEFORE'])) {
+                                $g1_pre = $language_data['PARSER_CONTROL']['KEYWORDS'][$key]['DISALLOWED_BEFORE'];
+                            }
+                            if(isset($language_data['PARSER_CONTROL']['KEYWORDS'][$key]['DISALLOWED_AFTER'])) {
+                                $g1_post = $language_data['PARSER_CONTROL']['KEYWORDS'][$key]['DISALLOWED_AFTER'];
+                            }
+
+                            if(isset($language_data['PARSER_CONTROL']['KEYWORDS'][$key2]['DISALLOWED_BEFORE'])) {
+                                $g2_pre = $language_data['PARSER_CONTROL']['KEYWORDS'][$key2]['DISALLOWED_BEFORE'];
+                            }
+                            if(isset($language_data['PARSER_CONTROL']['KEYWORDS'][$key2]['DISALLOWED_AFTER'])) {
+                                $g2_post = $language_data['PARSER_CONTROL']['KEYWORDS'][$key2]['DISALLOWED_AFTER'];
+                            }
+
+                            if($g1_pre != $g2_pre || $g1_post != $g2_post) {
+                                continue;
+                            }
+                        }
                         report_error(TYPE_WARNING, "Language file contains cross-group duplicate keyword '$kw' in \$language_data['KEYWORDS'][$key] and \$language_data['KEYWORDS'][$key2]!");
                     }
                 }
@@ -626,4 +670,4 @@ echo sprintf("%.2f", $time_diff);
 
 <div id="footer">GeSHi &copy; 2004-2007 Nigel McNie, 2007-2008 Benny Baumann, released under the GNU GPL</div>
 </body>
-</html>
+</html>
\ No newline at end of file
